@@ -6,10 +6,10 @@ BEGIN {
   $Gentoo::Perl::Distmap::Role::Serialize::AUTHORITY = 'cpan:KENTNL';
 }
 {
-  $Gentoo::Perl::Distmap::Role::Serialize::VERSION = '0.1.3';
+  $Gentoo::Perl::Distmap::Role::Serialize::VERSION = '0.1.4';
 }
 
-# ABSTRACT: Basic utilities for serialising/sorting/indexing Distmap nodes.
+# ABSTRACT: Basic utilities for serialising/sorting/indexing C<Distmap> nodes.
 
 use Moo::Role;
 
@@ -33,17 +33,18 @@ no Moo::Role;
 1;
 
 __END__
+
 =pod
 
 =encoding utf-8
 
 =head1 NAME
 
-Gentoo::Perl::Distmap::Role::Serialize - Basic utilities for serialising/sorting/indexing Distmap nodes.
+Gentoo::Perl::Distmap::Role::Serialize - Basic utilities for serialising/sorting/indexing C<Distmap> nodes.
 
 =head1 VERSION
 
-version 0.1.3
+version 0.1.4
 
 =head1 ROLE-REQUIRED METHODS
 
@@ -55,7 +56,7 @@ version 0.1.3
 
 =head2 hash
 
-Returns SHA1 of pp($instance->to_rec)
+Returns C<SHA1> of C<<pp($instance->to_rec)>>
 
   $astring = $instance->hash()
 
@@ -65,10 +66,9 @@ Kent Fredric <kentfredric@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Kent Fredric <kentfredric@gmail.com>.
+This software is copyright (c) 2013 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
